==> moodle-latest-2.1.05_20120412.zip: moodle/enrol/category/db/events.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * category enrolment plugin event handler definition.
 *
 * @package    enrol
 * @subpackage category
 * @copyright  2010 Petr Skoda {@link http://skodak.org}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

/* List of handlers */
$handlers = array (
    'role_assigned' => array (
        'handlerfile'      => '/enrol/category/locallib.php',
        'handlerfunction'  => array('enrol_category_handler', 'role_assigned'),
        'schedule'         => 'instant',
        'internal'         => 1,
    ),

    'role_unassigned' => array (
        'handlerfile'      => '/enrol/category/locallib.php',
        'handlerfunction'  => array('enrol_category_handler', 'role_unassigned'),
        'schedule'         => 'instant',
        'internal'         => 1,
    ),

);

==> moodle-latest-2.3.01_20120721.zip: moodle/enrol/category/db/events.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Category enrolment plugin event handler definition.
 *
 * @package enrol_category
 * @category event
 * @copyright 2010 Petr Skoda {@link http://skodak.org}
 * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

/* List of handlers */
$handlers = array (
    'role_assigned' => array (
        'handlerfile'      => '/enrol/category/locallib.php',
        'handlerfunction'  => array('enrol_category_handler', 'role_assigned'),
        'schedule'         => 'instant',
        'internal'         => 1,
    ),

    'role_unassigned' => array (
        'handlerfile'      => '/enrol/category/locallib.php',
        'handlerfunction'  => array('enrol_category_handler', 'role_unassigned'),
        'schedule'         => 'instant',
        'internal'         => 1,
    ),

);
